==> fine-web-0.0.1-20220919.091035-231.jar: beetlsql/base/BasMessage.md <==
BaseFlowSendInfo
===
select @pageTag(){
		z.*
	 @}
from
(
with w as
 (select t.*,
         row_number() over(partition by t.processinstid order by t.starttime) rn
    from WF_WORKITEM t),
s as
 (select t.*,
         row_number() over(partition by t.processinstid order by t.starttime desc) rn
    from WF_WORKITEM t),
b as
 (select bas.*,
         row_number() over(partition by bas.processinstid order by bas.sendtime desc) rn
    from BAS_MESSAGE bas where bas.msg_type = '1')
select 
distinct w.processinstid,
                w.processdefname,
                p.processchname,
                (case
                  when b.is_use = 'N' then
                   '已完成'
                  when b.is_use = 'Y' then
                   '流程中'
                end) status,
                a.account_id fqr_by,
                a.account_name fqr_name,
                w.workitemname fqr_itemname,
                DATE_FORMAT(w.starttime,'%Y-%m-%d %H:%i:%s') starttime,w.endtime,                 
                b.busi_main_id,
                b.form_code,                         
                (case
                  when b.is_use = 'N' then
                   null
                  when b.is_use = 'Y' then
                   s.workitemname
                end)  dq_itemname,
                (case
                  when b.is_use = 'N' then
                   null
                  when b.is_use = 'Y' then
                   (select group_concat(re.account_id) from BAS_MESSAGE_RECEIVE re where re.account_id != #admin# and re.msg_id = b.msg_id and re.is_deal = 'N')
                end)  dq_by,
                (case
                  when b.is_use = 'N' then
                   null
                  when b.is_use = 'Y' then
                   (select group_concat(dq.account_name) from BAS_MESSAGE_RECEIVE re,bas_emp_account dq where re.account_id != #admin# and dq.account_id = re.account_id and re.msg_id = b.msg_id and re.is_deal = 'N')
                end)  dq_name
from w, bas_emp_account a, WF_PROCESSDEFINE p, b,s
 where w.rn = 1
   and a.account_id = w.participant
   and w.processdefname = p.processdefname
   and w.processinstid = b.processinstid
   and b.rn = 1
   and s.rn = 1
   and w.processinstid = s.processinstid
) z
where 1 = 1
@if(!isEmpty(search)){
   and (
       z.fqr_name like #search#   or
       z.processchname like #search# or
       z.dq_name like #search#
       )
@}
@if(!isEmpty(status)){
   and z.status = #status#
@}
@pageIgnoreTag(){
	order by z.starttime desc
@}


selectWin
===
select @pageTag(){ 
	t.*,
	getaccountname(w.creator) AS creator_Text,
	to_char(t.sendtime, 'yyyy"年"mm"月"dd"日" HH24:mi:ss') AS sendtime_Text
@}
  from bas_message t, wf_processinst w
 where w.processinstid = t.processinstid
   and t.is_use = 'Y'
   and t.msg_type = #msgType#
   and w.creator = #loginuser.accountid#
   and w.currentstate = 12
@if(!isEmpty(filterflowid)){
	and t.processinstid not in (#join(filterflowid)#)
  
@}
@if(!isEmpty(search)){
   and (
       t.form_code like #search#   or
       t.msg_title like #search# or
       t.busi_main_id like #search# or
       t.msg_params like #search# or
       t.processinstid like #search# 
)@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.sendtime desc 
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

selectCheckFlowWin
===
select @pageTag(){ 
	t.*,
	getaccountname(w.creator) AS creator_Text,
	to_char(t.sendtime, 'yyyy"年"mm"月"dd"日" HH24:mi:ss') AS sendtime_Text
@}
  from bas_message t, wf_processinst w
 where w.processinstid   in ( select z.processinstid from (
							select f.processinstid,f.requisition_id  from Gm_Assets_Arrival f where f.is_use = 'Y' 
							union all 
							select f.processinstid,f.requisition_id  from Gm_Assets_Arrival_Fw f where f.is_use = 'Y') z 
							where 1=1 and z.requisition_id = #conId#)
	and instr('GmAssetsArrival,GmAssetsArrivalFw',t.form_code)>0
   and t.is_use = 'Y'
   and t.msg_type = #msgType#
   and w.creator = #loginuser.accountid#
   and w.currentstate = 12
@if(!isEmpty(filterflowid)){
	and t.processinstid not in (#join(filterflowid)#)
  
@}
@if(!isEmpty(search)){
   and (
       t.form_code like #search#   or
       t.msg_title like #search# or
       t.busi_main_id like #search# or
       t.msg_params like #search# or
       t.processinstid like #search# 
)@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.sendtime desc 
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

FindConnectFlow
===
select @pageTag(){
				t.FLOW_RELATE_ID,
		t.RELATE_FORM_CODE,
		t.RELATE_BIZ_ID,
		t.REMARK,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.IS_USE,
		m.msg_id,
		m.busi_main_id,
		m.form_code,
		m.processinstid,
		m.msg_title,
		m.msg_params,
		getaccountname(m.sender) AS creator_Text,
		to_char(m.sendtime, 'yyyy"年"mm"月"dd"日" HH24:mi:ss') AS sendtime_Text
	 @}
from PUB_FLOW_RELATE t
left join bas_message m
  on m.msg_id = t.msg_id
  and m.is_use = 'Y'
 where t.is_use = 'Y'
@if(!isEmpty(busiMainId)){
	and t.relate_biz_id = #busiMainId#
@}
@if(!isEmpty(formCode)){
	and t.relate_form_code = #formCode#
@}


-- 获取我的流程 1:发起,2:已办,3:未办,4:超期
getMyFlow
===
select count(1) from (
select t.busi_main_id,t.processinstid,count(1)
  from bas_message t
  left join wf_processinst p
    on t.processinstid = p.processinstid
  left join bas_message_receive r 
  on r.msg_id = t.msg_id
 where 1=1 
@if(!isEmpty(myFLow)){
	@if(myFLow=='1'){
		and p.creator = #accountId#
	   and p.currentstate in (4, 10, 12)
	@}else if(myFLow=='2'){
		and r.ACCOUNT_ID = #accountId#
		and p.currentstate in (4, 10, 12)
		and r.is_deal = 'Y'
	@}else if(myFLow=='3'){
		and r.ACCOUNT_ID = #accountId#
		and p.currentstate in (4, 10)
		and r.is_deal = 'N'
	@}else if(myFLow=='0'){
		and 1=0
	@}
@}
group by t.busi_main_id,t.processinstid)

--获得当前登录人常用流程
getMyFlowCY
===
select @pageTag(){
     r.*,et.template_type,et.id
@}
from(select 
  bp.design_name, bp.flow_name, gf.form_code,count(1) AS count

from wf_processinst p, wf_processdefine pd, stf_business_process bp,BAS_MESSAGE gf

 where p.creator =#loginuser.accountid#
   and pd.processdefname = p.processinstname
   and pd.currentstate = 3
   and bp.design_name = p.processinstname
   and p.currentstate in (4, 10, 12)
   and p.PROCESSINSTID = gf.PROCESSINSTID
   
 group by p.processinstname,bp.design_name, bp.flow_name,gf.form_code
 
 order by bp.design_name, count(1) desc)r
 
 left join EDOC_TEMPLATE et
on r.design_name = et.flow_code

==> fine-web-0.0.2-20220909.090829-172.jar: beetlsql/base/BasMessage.md <==
BaseFlowSendInfo
===
select @pageTag(){
		z.*
	 @}
from
(
with w as
 (select t.*,
         row_number() over(partition by t.processinstid order by t.starttime) rn
    from WF_WORKITEM t),
s as
 (select t.*,
         row_number() over(partition by t.processinstid order by t.starttime desc) rn
    from WF_WORKITEM t),
b as
 (select bas.*,
         row_number() over(partition by bas.processinstid order by bas.sendtime desc) rn
    from BAS_MESSAGE bas where bas.msg_type = '1')
select 
distinct w.processinstid,
                w.processdefname,
                p.processchname,
                (case
                  when b.is_use = 'N' then
                   '已完成'
                  when b.is_use = 'Y' then
                   '流程中'
                end) status,
                a.account_id fqr_by,
                a.account_name fqr_name,
                w.workitemname fqr_itemname,
                DATE_FORMAT(w.starttime,'%Y-%m-%d %H:%i:%s') starttime,w.endtime,                 
                b.busi_main_id,
                b.form_code,                         
                (case
                  when b.is_use = 'N' then
                   null
                  when b.is_use = 'Y' then
                   s.workitemname
                end)  dq_itemname,
                (case
                  when b.is_use = 'N' then
                   null
                  when b.is_use = 'Y' then
                   (select group_concat(re.account_id) from BAS_MESSAGE_RECEIVE re where re.account_id != #admin# and re.msg_id = b.msg_id and re.is_deal = 'N')
                end)  dq_by,
                (case
                  when b.is_use = 'N' then
                   null
                  when b.is_use = 'Y' then
                   (select group_concat(dq.account_name) from BAS_MESSAGE_RECEIVE re,bas_emp_account dq where re.account_id != #admin# and dq.account_id = re.account_id and re.msg_id = b.msg_id and re.is_deal = 'N')
                end)  dq_name
from w, bas_emp_account a, WF_PROCESSDEFINE p, b,s
 where w.rn = 1
   and a.account_id = w.participant
   and w.processdefname = p.processdefname
   and w.processinstid = b.processinstid
   and b.rn = 1
   and s.rn = 1
   and w.processinstid = s.processinstid
) z
where 1 = 1
@if(!isEmpty(search)){
   and (
       z.fqr_name like #search#   or
       z.processchname like #search# or
       z.dq_name like #search#
       )
@}
@if(!isEmpty(status)){
   and z.status = #status#
@}
@pageIgnoreTag(){
	order by z.starttime desc
@}


selectWin
===
select @pageTag(){ 
	t.*,
	getaccountname(w.creator) AS creator_Text,
	to_char(t.sendtime, 'yyyy"年"mm"月"dd"日" HH24:mi:ss') AS sendtime_Text
@}
  from bas_message t, wf_processinst w
 where w.processinstid = t.processinstid
   and t.is_use = 'Y'
   and t.msg_type = #msgType#
   and w.creator = #loginuser.accountid#
   and w.currentstate = 12
@if(!isEmpty(filterflowid)){
	and t.processinstid not in (#join(filterflowid)#)
  
@}
@if(!isEmpty(search)){
   and (
       t.form_code like #search#   or
       t.msg_title like #search# or
       t.busi_main_id like #search# or
       t.msg_params like #search# or
       t.processinstid like #search# 
)@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.sendtime desc 
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

selectCheckFlowWin
===
select @pageTag(){ 
	t.*,
	getaccountname(w.creator) AS creator_Text,
	to_char(t.sendtime, 'yyyy"年"mm"月"dd"日" HH24:mi:ss') AS sendtime_Text
@}
  from bas_message t, wf_processinst w
 where w.processinstid   in ( select z.processinstid from (
							select f.processinstid,f.requisition_id  from Gm_Assets_Arrival f where f.is_use = 'Y' 
							union all 
							select f.processinstid,f.requisition_id  from Gm_Assets_Arrival_Fw f where f.is_use = 'Y') z 
							where 1=1 and z.requisition_id = #conId#)
	and instr('GmAssetsArrival,GmAssetsArrivalFw',t.form_code)>0
   and t.is_use = 'Y'
   and t.msg_type = #msgType#
   and w.creator = #loginuser.accountid#
   and w.currentstate = 12
@if(!isEmpty(filterflowid)){
	and t.processinstid not in (#join(filterflowid)#)
  
@}
@if(!isEmpty(search)){
   and (
       t.form_code like #search#   or
       t.msg_title like #search# or
       t.busi_main_id like #search# or
       t.msg_params like #search# or
       t.processinstid like #search# 
)@}
@pageIgnoreTag(){
	@if(isEmpty(sort)){
   	 order by t.sendtime desc 
    @}
    @if(!isEmpty(sort)){
   	 order by #text(sort)# #text(order)#
    @}
@}

FindConnectFlow
===
select @pageTag(){
				t.FLOW_RELATE_ID,
		t.RELATE_FORM_CODE,
		t.RELATE_BIZ_ID,
		t.REMARK,
		t.CREATE_ACCOUNT,
		t.CREATE_TIME,
		t.MODIFY_ACCOUNT,
		t.MODIFY_TIME,
		t.IS_USE,
		m.msg_id,
		m.busi_main_id,
		m.form_code,
		m.processinstid,
		m.msg_title,
		m.msg_params,
		getaccountname(m.sender) AS creator_Text,
		to_char(m.sendtime, 'yyyy"年"mm"月"dd"日" HH24:mi:ss') AS sendtime_Text
	 @}
from PUB_FLOW_RELATE t
left join bas_message m
  on m.msg_id = t.msg_id
  and m.is_use = 'Y'
 where t.is_use = 'Y'
@if(!isEmpty(busiMainId)){
	and t.relate_biz_id = #busiMainId#
@}
@if(!isEmpty(formCode)){
	and t.relate_form_code = #formCode#
@}


-- 获取我的流程 1:发起,2:已办,3:未办,4:超期
getMyFlow
===
select count(1) from (
select t.busi_main_id,t.processinstid,count(1)
  from bas_message t
  left join wf_processinst p
    on t.processinstid = p.processinstid
  left join bas_message_receive r 
  on r.msg_id = t.msg_id
 where 1=1 
@if(!isEmpty(myFLow)){
	@if(myFLow=='1'){
		and p.creator = #accountId#
	   and p.currentstate in (4, 10, 12)
	@}else if(myFLow=='2'){
		and r.ACCOUNT_ID = #accountId#
		and p.currentstate in (4, 10, 12)
		and r.is_deal = 'Y'
	@}else if(myFLow=='3'){
		and r.ACCOUNT_ID = #accountId#
		and p.currentstate in (4, 10)
		and r.is_deal = 'N'
	@}else if(myFLow=='0'){
		and 1=0
	@}
@}
group by t.busi_main_id,t.processinstid)

--获得当前登录人常用流程
getMyFlowCY
===
select @pageTag(){
     r.*,et.template_type,et.id
@}
from(select 
  bp.design_name, bp.flow_name, gf.form_code,count(1) AS count

from wf_processinst p, wf_processdefine pd, stf_business_process bp,BAS_MESSAGE gf

 where p.creator =#loginuser.accountid#
   and pd.processdefname = p.processinstname
   and pd.currentstate = 3
   and bp.design_name = p.processinstname
   and p.currentstate in (4, 10, 12)
   and p.PROCESSINSTID = gf.PROCESSINSTID
   
 group by p.processinstname,bp.design_name, bp.flow_name,gf.form_code
 
 order by bp.design_name, count(1) desc)r
 
 left join EDOC_TEMPLATE et
on r.design_name = et.flow_code
 
getAccountUndoMsgCount
===
SELECT count(1)
  FROM BAS_MESSAGE t 
  join (SELECT r.msg_id 
 FROM  bas_message         s,BAS_MESSAGE_RECEIVE r
where  r.account_id = #accountId#
 and r.is_deal = 'N' 
	AND s.msg_id = r.msg_id
	AND s.is_use = 'Y'
	and s.msg_type=1
UNION
SELECT s.msg_id 
     FROM WF_AGENT            a,
			gen_form            f,
			bas_message         s,
			bas_message_receive e
WHERE s.form_code = f.form_code
	AND s.msg_id = e.msg_id
	AND e.account_id = a.agent_to_account
	AND s.is_use = 'Y'
	AND e.is_deal = 'N'
 and a.agent_account = #accountId#
	and s.msg_type=1
	AND a.is_use = 'Y'
	AND ((FIND_IN_SET( a.agent_content ,f.flow_cat_id )>0 AND
			a.end_date > now() AND
			(a.cancel_date IS NULL OR a.cancel_date > now())) OR
			a.agent_type = '2')) r
    on r.msg_id = t.msg_id
